document.addEventListener('DOMContentLoaded', function () {
    // Array to store product details
    var products = [];

    // Function to add a product to the cart
    function addToCart(btn) {
        var productContainer = btn.parentElement;
        var productName = productContainer.querySelector(".name").innerText;
        var selectedSize = productContainer.querySelector(".sizeSelect").value;
        var selectedColor = productContainer.querySelector(".colorSelect").value;
        var quantity = parseInt(productContainer.querySelector(".quantityInput").value);
        var price = parseFloat(productContainer.querySelector(".price").innerText.substring(1));

        if (selectedSize === "Select Size" || selectedColor === "Select Color" || isNaN(quantity) || quantity <= 0) {
            alert("Please select size, color, and quantity before adding to cart.");
            return;
        }

        products.push({ name: productName, size: selectedSize, color: selectedColor, quantity: quantity, price: price });

        updateCart();
    }

    // Function to update the cart display
    function updateCart() {
        var cartTableBody = document.querySelector('.cart-page table tbody');
        cartTableBody.innerHTML = '';
        var totalPrice = 0;

        products.forEach(product => {
            var tr = document.createElement('tr');
            tr.innerHTML = `
                <td>${product.name} - ${product.size} - ${product.color}</td>
                <td>${product.quantity}</td>
                <td>$${(product.quantity * product.price).toFixed(2)}</td>
            `;
            cartTableBody.appendChild(tr);
            totalPrice += product.quantity * product.price;
        });

        document.querySelector('.total-price td:nth-child(2)').textContent = '$' + totalPrice.toFixed(2);
    }

    // Fetch product details from each product page
    fetchProductDetails('products-details.html');
    fetchProductDetails('products-details1.html');
    fetchProductDetails('products-details2.html');
    fetchProductDetails('products-details3.html');
    fetchProductDetails('products-details4.html');
    fetchProductDetails('products-details5.html');

    // Function to fetch product details from a specific product page
    function fetchProductDetails(productPageURL) {
        // Make a fetch request to get the product details
        fetch(productPageURL)
            .then(response => response.text())
            .then(data => {
                var parser = new DOMParser();
                var htmlDocument = parser.parseFromString(data, 'text/html');

                var productName = htmlDocument.querySelector('.col-2 h1').innerText;
                var productPrice = parseFloat(htmlDocument.querySelector('.col-2 h4').innerText.substring(1));

                // Add the product details to the products array
                products.push({ name: productName, price: productPrice });

                // Update the cart display after fetching each product
                updateCart();
            })
           .catch(error => console.error('Error fetching product details:', error.message));
    }
});
